import { getRecordSlug, slug, isNonEmptyString, newShortId } from "primeobjects-helper-util";
import { isNil } from "lodash";
export var getOrganizationNameBasedUrl = function (solution, organization) {
    var orgHasItsOwnSubDomain = isNonEmptyString(organization.subdomain);
    var subdomain = orgHasItsOwnSubDomain
        ? organization.subdomain
        : organization.slug;
    return "https://".concat(subdomain, ".").concat(solution.domain, "/");
};
export var getOrganizationCanonicalUrl = function (solution, organization) {
    return "https://".concat(organization.shortId, ".").concat(solution.domain, "/");
};
export var getWebAddressesRows = function (props) {
    var _a, _b;
    var sectionLine = props.sectionLine, solution = props.solution, organization = props.organization, record = props.record, path = props.path, canonicalEndpointLabel = props.canonicalEndpointLabel, nameBasedEndpointLabel = props.nameBasedEndpointLabel, fieldLabelForNameBasedEndpoint = props.fieldLabelForNameBasedEndpoint, hideSection = props.hideSection, supportNameBasedSlug = props.supportNameBasedSlug;
    if (!isNonEmptyString(record.shortId))
        record.shortId = newShortId();
    var fieldNameForAPIName = supportNameBasedSlug
        ? "nameBasedSlug"
        : props.fieldNameForAPIName;
    var apiNameFieldHasValue = !isNil(fieldNameForAPIName) &&
        isNonEmptyString(record[fieldNameForAPIName]);
    var webSlug = apiNameFieldHasValue
        ? slug(record[fieldNameForAPIName])
        : getRecordSlug(record);
    var nameBasedEndpoint = (_a = props.nameBasedEndpoint) !== null && _a !== void 0 ? _a : "".concat(getOrganizationNameBasedUrl(solution, organization)).concat(path, "/").concat(webSlug);
    var canonicalEndpoint = (_b = props.canonicalEndpoint) !== null && _b !== void 0 ? _b : "".concat(getOrganizationCanonicalUrl(solution, organization)).concat(path, "/").concat(record.shortId);
    return [
        !hideSection && {
            fields: [
                {
                    wrapperStyle: {
                        marginBottom: 0
                    },
                    name: "webAddressSection",
                    type: "section",
                    line: sectionLine !== null && sectionLine !== void 0 ? sectionLine : "Web addresses and endpoints"
                }
            ]
        },
        supportNameBasedSlug && {
            fields: [
                {
                    name: "nameBasedSlug",
                    label: nameBasedEndpointLabel !== null && nameBasedEndpointLabel !== void 0 ? nameBasedEndpointLabel : "The path/slug for name-based web address",
                    type: "single-line-input",
                    alwaysShowLabel: true,
                    note: "The text in this field will be used as the path/slug of the name-based web address."
                }
            ]
        },
        isNonEmptyString(nameBasedEndpoint) && {
            fields: [
                {
                    name: "nameBasedEndpoint",
                    label: nameBasedEndpointLabel !== null && nameBasedEndpointLabel !== void 0 ? nameBasedEndpointLabel : "Name-based web address",
                    value: nameBasedEndpoint,
                    useFieldValue: true,
                    format: "url",
                    type: "single-line-input",
                    alwaysShowLabel: true,
                    disabled: true,
                    note: apiNameFieldHasValue
                        ? "This URL will change while the ".concat(fieldLabelForNameBasedEndpoint !== null && fieldLabelForNameBasedEndpoint !== void 0 ? fieldLabelForNameBasedEndpoint : "name", " is changed.")
                        : "Although this URL will change while the ".concat(fieldLabelForNameBasedEndpoint !== null && fieldLabelForNameBasedEndpoint !== void 0 ? fieldLabelForNameBasedEndpoint : "name", " is changed , all previous URLs will always work.")
                }
            ]
        },
        isNonEmptyString(canonicalEndpoint) && {
            fields: [
                {
                    name: "canonicalEndpoint",
                    label: canonicalEndpointLabel !== null && canonicalEndpointLabel !== void 0 ? canonicalEndpointLabel : "Canonical web address",
                    value: canonicalEndpoint,
                    useFieldValue: true,
                    format: "url",
                    type: "single-line-input",
                    alwaysShowLabel: true,
                    disabled: true,
                    note: "This URL will never change."
                }
            ]
        }
    ];
};
//# sourceMappingURL=web-addresses-rows.js.map